Enum prettytable::Attr [−][src]
pub enum Attr {
Bold,
Dim,
Italic(bool),
Underline(bool),
Blink,
Standout(bool),
Reverse,
Secure,
ForegroundColor(u32),
BackgroundColor(u32),
}Terminal attributes for use with term.attr().
Most attributes can only be turned on and must be turned off with term.reset(). The ones that can be turned off explicitly take a boolean value. Color is also represented as an attribute for convenience.
Variants
BoldBold (or possibly bright) mode
DimDim mode, also called faint or half-bright. Often not supported
Italic(bool)Italics mode. Often not supported
Underline(bool)Underline mode
BlinkBlink mode
Standout(bool)Standout mode. Often implemented as Reverse, sometimes coupled with Bold
ReverseReverse mode, inverts the foreground and background colors
SecureSecure mode, also called invis mode. Hides the printed text
ForegroundColor(u32)Convenience attribute to set the foreground color
BackgroundColor(u32)Convenience attribute to set the background color