Crate prettytable

Crate prettytable 

A formatted and aligned table printer written in rust

Modules

color
Terminal color definitions
format
Define table formatting utilities

Macros

cell
This macro simplifies Cell creation
ptable
Create a table with table! macro, print it to standard output, then return this table for future usage.
row
This macro simplifies Row creation
table
Create a table filled with some values

Structs

Cell
Represent a table cell containing a string.
ColumnIter
Iterator over immutable cells in a column
ColumnIterMut
Iterator over mutable cells in a column
Row
Represent a table row made of cells
Table
An owned printable table
TableSlice
A borrowed immutable Table slice A TableSlice is obtained by slicing a Table with the Slice::slice method.

Enums

Attr
Terminal attributes for use with term.attr().

Traits

AsTableSlice
Trait implemented by types which can be sliced
Slice
Trait implemented by types which can be sliced