Module prettytable::format
[−]
[src]
Define table formatting utilities
Structs
| LineSeparator |
Contains the character used for printing a line separator |
| TableFormat |
Contains the table formatting rules |
Enums
| Align |
Alignment for cell's content |
Constants
| EQU_PLUS_SEP |
A line separator mad of |
| FORMAT_DEFAULT |
Default table format, printing a table like this : |
| FORMAT_NO_BORDER |
Format for printing a table without any separators (only alignment) |
| FORMAT_NO_COLSEP |
No column seprarator |
| FORMAT_NO_LINESEP |
With no line or title separator |
| FORMAT_NO_LINESEP_WITH_TITLE |
With no line separator, but with title separator |
| FORMAT_NO_TITLE |
Similar to |
| MINUS_PLUS_SEP |
A line separator mad of |