Struct prettytable::format::LineSeparator [−][src]
pub struct LineSeparator { /* fields omitted */ }Contains the character used for printing a line separator
Methods
impl LineSeparator[src]
impl LineSeparatorpub fn new(line: char, junc: char, ljunc: char, rjunc: char) -> LineSeparator[src]
pub fn new(line: char, junc: char, ljunc: char, rjunc: char) -> LineSeparatorCreate a new line separator instance where line is the character used to separate 2 lines
and junc is the one used for junctions between columns and lines